@@ -20,13 +20,12 @@ import pwd
 import shutil
 import sys
 
-from devscripts.logger import Logger
-
 from distro_info import UbuntuDistroInfo
 
 from launchpadlib.launchpad import Launchpad
 
 from ubuntutools import subprocess
+from ubuntutools.logger import Logger
 from ubuntutools.update_maintainer import (update_maintainer,
                                            MaintainerUpdateException)
 from ubuntutools.question import input_number
@@ -192,6 +191,9 @@ def get_open_ubuntu_bug_task(launchpad, bug, branch=None):
     ubuntu_tasks = [x for x in bug_tasks if x.is_ubuntu_task()]
     if branch:
         branch = branch.split('/')
+        # Non-production LP?
+        if len(branch) > 5:
+            branch = branch[3:]
 
     if len(ubuntu_tasks) == 0:
         Logger.error("No Ubuntu bug task found on bug #%i." % (bug.id))
